==> owncloud-10.0.3.tgz: owncloud/core/l10n/ug.js <==
OC.L10N.register(
    "core",
    {
    "Sunday" : "يەكشەنبە",
    "Monday" : "دۈشەنبە",
    "Tuesday" : "سەيشەنبە",
    "Wednesday" : "چارشەنبە",
    "Thursday" : "پەيشەنبە",
    "Friday" : "جۈمە",
    "Saturday" : "شەنبە",
    "Sun." : "يەك",
    "Mon." : "دۈش",
    "Tue." : "سەي",
    "Wed." : "چار",
    "Thu." : "پەي",
    "Fri." : "جۈم",
    "Sat." : "شەن",
    "January" : "قەھرىتان",
    "February" : "ھۇت",
    "March" : "نەۋرۇز",
    "April" : "ئۇمۇت",
    "May" : "باھار",
    "June" : "سەپەر",
    "July" : "چىللە",
    "August" : "تومۇز",
    "September" : "مىزان",
    "October" : "ئوغۇز",
    "November" : "ئوغلاق",
    "December" : "كۆنەك",
    "Jan." : "قەھرىتان",
    "Feb." : "ھۇت",
    "Mar." : "نەۋرۇز",
    "Apr." : "ئۇمۇت",
    "May." : "باھار",
    "Jun." : "سەپەر",
    "Jul." : "چىللە",
    "Aug." : "تومۇز",
    "Sep." : "مىزان",
    "Oct." : "ئوغۇز",
    "Nov." : "ئوغلاق",
    "Dec." : "كۆنەك",
    "Settings" : "تەڭشەكلەر",
    "Saving..." : "ساقلاۋاتىدۇ…",
    "No" : "ياق",
    "Yes" : "ھەئە",
    "Ok" : "جەزملە",
    "Cancel" : "ۋاز كەچ",
    "Error" : "خاتالىق",
    "Edit" : "تەھرىر",
    "Remove" : "چىقىرىۋەت",
    "Password" : "ئىم",
    "Name" : "ئاتى",
    "Save" : "ساقلا",
    "group" : "گۇرۇپپا",
    "Unshare" : "ھەمبەھىرلىمە",
    "delete" : "ئۆچۈر",
    "Share" : "ھەمبەھىر",
    "Warning" : "ئاگاھلاندۇرۇش",
    "Delete" : "ئۆچۈر",
    "Rename" : "ئات ئۆزگەرت",
    "Add" : "قوش",
    "Personal" : "شەخسىي",
    "Users" : "ئىشلەتكۈچىلەر",
    "Apps" : "ئەپلەر",
    "Help" : "ياردەم",
    "Username" : "ئىشلەتكۈچى ئاتى",
    "Finish setup" : "تەڭشەك تامام",
    "Log out" : "تىزىمدىن چىق",
    "Search" : "ئىزدە",
    "New password" : "يېڭى ئىم"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.10.tgz: owncloud/core/l10n/ug.js <==
OC.L10N.register(
    "core",
    {
    "Sunday" : "يەكشەنبە",
    "Monday" : "دۈشەنبە",
    "Tuesday" : "سەيشەنبە",
    "Wednesday" : "چارشەنبە",
    "Thursday" : "پەيشەنبە",
    "Friday" : "جۈمە",
    "Saturday" : "شەنبە",
    "Sun." : "يەك",
    "Mon." : "دۈش",
    "Tue." : "سەي",
    "Wed." : "چار",
    "Thu." : "پەي",
    "Fri." : "جۈم",
    "Sat." : "شەن",
    "January" : "قەھرىتان",
    "February" : "ھۇت",
    "March" : "نەۋرۇز",
    "April" : "ئۇمۇت",
    "May" : "باھار",
    "June" : "سەپەر",
    "July" : "چىللە",
    "August" : "تومۇز",
    "September" : "مىزان",
    "October" : "ئوغۇز",
    "November" : "ئوغلاق",
    "December" : "كۆنەك",
    "Jan." : "قەھرىتان",
    "Feb." : "ھۇت",
    "Mar." : "نەۋرۇز",
    "Apr." : "ئۇمۇت",
    "May." : "باھار",
    "Jun." : "سەپەر",
    "Jul." : "چىللە",
    "Aug." : "تومۇز",
    "Sep." : "مىزان",
    "Oct." : "ئوغۇز",
    "Nov." : "ئوغلاق",
    "Dec." : "كۆنەك",
    "Settings" : "تەڭشەكلەر",
    "Saving..." : "ساقلاۋاتىدۇ…",
    "No" : "ياق",
    "Yes" : "ھەئە",
    "Ok" : "جەزملە",
    "Cancel" : "ۋاز كەچ",
    "Error" : "خاتالىق",
    "Edit" : "تەھرىر",
    "Remove" : "چىقىرىۋەت",
    "Password" : "ئىم",
    "Name" : "ئاتى",
    "Save" : "ساقلا",
    "group" : "گۇرۇپپا",
    "Unshare" : "ھەمبەھىرلىمە",
    "delete" : "ئۆچۈر",
    "Share" : "ھەمبەھىر",
    "Warning" : "ئاگاھلاندۇرۇش",
    "Delete" : "ئۆچۈر",
    "Rename" : "ئات ئۆزگەرت",
    "Add" : "قوش",
    "Personal" : "شەخسىي",
    "Users" : "ئىشلەتكۈچىلەر",
    "Apps" : "ئەپلەر",
    "Help" : "ياردەم",
    "Username" : "ئىشلەتكۈچى ئاتى",
    "Finish setup" : "تەڭشەك تامام",
    "Log out" : "تىزىمدىن چىق",
    "Search" : "ئىزدە",
    "New password" : "يېڭى ئىم",
    "Copy to clipboard" : "چاپلاش تاختىسىغا كۆچۈر"
},
"nplurals=1; plural=0;");
